# Mobility Rate by College Bubble Chart

This example will demonstrate how to implement a bubble chart in [D3.js](https://d3js.org/) version 5 with legends using [d3-legend](https://d3-legend.susielu.com/) by [Susie Lu](https://susielu.com/).

The data comes from [Opportunity Insights](https://opportunityinsights.org/data/), which is a "non-partisan, not-for-profit organization based at Harvard University" that puts out public datasets produced for on their research.

We will specifically use data from the [Mobility Report Cards](https://opportunityinsights.org/paper/mobilityreportcards/) project. The dataset is titled "Mobility Report Cards: Preferred Estimates of Access and Mobility Rates by College" and can be accessed via these direct links:

[mrc_table1.csv](https://opportunityinsights.org/wp-content/uploads/2018/03/mrc_table1.csv)  
[Codebook-MRC-Table-1.pdf](https://opportunityinsights.org/wp-content/uploads/2018/03/Codebook-MRC-Table-1.pdf)

The original CSV file is [replicated on this gist](#file-mrc_table1-csv) to avoid CORS issues when viewing this example on [bl.ocks.org](https://bl.ocks.org/sjengle/22051097a8090fa227cbd80cdc2bad03) or [blockbuilder.org](https://blockbuilder.org/sjengle/22051097a8090fa227cbd80cdc2bad03).

We will filter this data to focus only on those universities located in California, which includes the [University of San Francisco](https://www.usfca.edu/).

## References

- [Github Gist](https://gist.github.com/sjengle/22051097a8090fa227cbd80cdc2bad03)
- [Bl.ocks.org](https://bl.ocks.org/sjengle/22051097a8090fa227cbd80cdc2bad03/fe2392c37190db082704c49272aef8a653ddcae8)
- [Blockbuilder.org](https://blockbuilder.org/sjengle/22051097a8090fa227cbd80cdc2bad03)
- [Vizhub.com](https://vizhub.com/sjengle/d788e83f632b4158b0786304710a692e)

## Tableau Prototype

![Bubble Chart Prototype](https://gist.githubusercontent.com/sjengle/22051097a8090fa227cbd80cdc2bad03/raw/fe2392c37190db082704c49272aef8a653ddcae8/prototype.png)

See the [Tableau Workbook](https://us-west-2b.online.tableau.com/#/site/usfcs360spring2020/workbooks/177770?:origin=card_share_link) for how to create this prototype. It is important to make sure count appears first on the marks card, which makes sure the smaller bubbles are drawn on top of the larger ones.

Below is the sheet description from Tableau to help rebuild it:

#### Description of "Mobility vs Income"

`Median Parent Household Income` vs. `Mobility Rate`.  Color shows details about `Trend of Parents in Bottom 20%`.  Size shows details about `Average Children per Cohort`.  The marks are labeled by `College Name`. The data is filtered on `State`, which keeps `CA`.

#### Marks

The mark type is `Circle`.
The marks are labeled by `College Name`.
Stacked marks is `off`.

#### Shelves

| Label | Renamed Field | Original Field |
|------:|:--------------|:---------------|
| **Rows:** | Mobility Rate | `mr_kq5_pq1` |
| **Columns:** | Median Parent Household Income | `par_median` |
| **Filters:** | State | `state` |
| **Text:** | College Name | `name` |
| **Color:** | Trend of Parents in Bottom 20% | `trend_parq1` |
| **Size:** | Average Children per Cohort | `count` |

#### Dimensions

- `Average Children per Cohort` ranges from 50 to 8556 on this sheet.

- `College Name` has 168 members on this sheet  
  - **Members:** CalState LA; California State Polytechnic University, Pomona; Crimson Technical College; Glendale Community College; University Of California, Irvine; ...

- `State` has 1 members on this sheet
  - **Members:** CA

- `Trend of Parents in Bottom 20%` ranges from -17.57 to 31.79 on this sheet.

#### Measures

- `Mobility Rate` ranges from 0.000 to 9.918 on this sheet.

- `Median Parent Household Income` ranges from 29,300 to 172,600 on this sheet.
